:tocdepth: 2

***
API
***

CLI
===

.. automodule:: pupil_labs.lsl_relay.cli
    :members:
    :undoc-members:
    :show-inheritance:

Relay
===========

.. automodule:: pupil_labs.lsl_relay.relay
    :members:
    :undoc-members:
    :show-inheritance:

Channels
===========

.. automodule:: pupil_labs.lsl_relay.channels
    :members:
    :undoc-members:
    :show-inheritance:

Outlets
==========

.. automodule:: pupil_labs.lsl_relay.outlets
    :members:
    :undoc-members:
    :show-inheritance:
